Object.defineProperty(exports, "__esModule", { value: true });
exports.sourceToAst = void 0;
const envStore_1 = require("./envStore");
const core_1 = require("@babel/core");
const extractEnvironmentVariables = (path, codeAsString) => {
    path.node.arguments[1].properties.forEach((environmentProperty) => {
        const keyValueAsString = codeAsString.substring(environmentProperty.start, environmentProperty.end);
        const finalObj = {};
        finalObj.required = !keyValueAsString.includes('default');
        if (keyValueAsString.includes('devDefault')) {
            finalObj.devRequired = false;
        }
        envStore_1.default.addFunction([
            {
                [keyValueAsString.substring(0, keyValueAsString.indexOf(':') + 1)]: finalObj,
            },
        ]);
    });
};
/**
 * Expects an AST tree with start of the node
 * Extract the object part of the string and convert to
 * `
 *  {
 *    NODE_ENV: { required: true },
 *    ENV1: { required: false }, // if `default` exist
 *    ENV2: { devRequired: false }, // if `devDefault` exist
 * }
 * `
 */
let ranForPublicConfig = false;
const currentKeys = [];
function envLogger() {
    return {
        visitor: {
            CallExpression(path, state) {
                var _a, _b, _c, _d, _e, _f;
                if (((_a = path.node.callee) === null || _a === void 0 ? void 0 : _a.name) === 'cleanEnv' ||
                    (((_c = (_b = path.node.callee) === null || _b === void 0 ? void 0 : _b.object) === null || _c === void 0 ? void 0 : _c.name) === 'envalid' && ((_e = (_d = path.node.callee) === null || _d === void 0 ? void 0 : _d.property) === null || _e === void 0 ? void 0 : _e.name) === 'cleanEnv')) {
                    extractEnvironmentVariables(path, state.file.code);
                }
                if (((_f = path.node.callee) === null || _f === void 0 ? void 0 : _f.type) === 'SequenceExpression') {
                    let hasCleanEnvString = false;
                    path.node.callee.expressions.forEach((seqExp) => {
                        var _a, _b;
                        if (((_a = seqExp === null || seqExp === void 0 ? void 0 : seqExp.object) === null || _a === void 0 ? void 0 : _a.name) === 'cleanEnv') {
                            hasCleanEnvString = true;
                        }
                        if (((_b = seqExp === null || seqExp === void 0 ? void 0 : seqExp.property) === null || _b === void 0 ? void 0 : _b.name) === 'cleanEnv') {
                            hasCleanEnvString = true;
                        }
                    });
                    if (hasCleanEnvString) {
                        extractEnvironmentVariables(path, state.file.code);
                    }
                }
            },
            VariableDeclarator(path) {
                var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
                if (((_b = (_a = path.node) === null || _a === void 0 ? void 0 : _a.id) === null || _b === void 0 ? void 0 : _b.name) === 'publicEnv') {
                    ranForPublicConfig = true;
                    if ((_c = path.node) === null || _c === void 0 ? void 0 : _c.init.elements) {
                        (_e = (_d = path.node) === null || _d === void 0 ? void 0 : _d.init) === null || _e === void 0 ? void 0 : _e.elements.forEach((stringNode) => {
                            if (stringNode === null || stringNode === void 0 ? void 0 : stringNode.value) {
                                currentKeys.push(stringNode === null || stringNode === void 0 ? void 0 : stringNode.value);
                            }
                        });
                    }
                    else if ((_g = (_f = path.node) === null || _f === void 0 ? void 0 : _f.init) === null || _g === void 0 ? void 0 : _g.properties) {
                        (_j = (_h = path.node) === null || _h === void 0 ? void 0 : _h.init) === null || _j === void 0 ? void 0 : _j.properties.forEach((publicEnvproperty) => {
                            var _a, _b;
                            if ((_a = publicEnvproperty === null || publicEnvproperty === void 0 ? void 0 : publicEnvproperty.value) === null || _a === void 0 ? void 0 : _a.name) {
                                currentKeys.push((_b = publicEnvproperty === null || publicEnvproperty === void 0 ? void 0 : publicEnvproperty.value) === null || _b === void 0 ? void 0 : _b.name);
                            }
                        });
                    }
                    else if ((_l = (_k = path.node) === null || _k === void 0 ? void 0 : _k.init) === null || _l === void 0 ? void 0 : _l.value) {
                        if (path.node.init.value) {
                            currentKeys.push(path.node.init.value);
                        }
                    }
                }
            },
        },
        post() {
            if (ranForPublicConfig) {
                envStore_1.default.currentKeys = currentKeys;
            }
        },
    };
}
exports.default = envLogger;
const sourceToAst = (source) => {
    (0, core_1.transformSync)(source, {
        // Need to pass a filename when manually calling babel
        filename: 'file.ts',
        presets: ['@babel/preset-env', '@babel/preset-typescript'],
        plugins: [envLogger],
    });
};
exports.sourceToAst = sourceToAst;
//# sourceMappingURL=envLogger.js.map