Object.defineProperty(exports, "__esModule", { value: true });
class EnvStore {
    constructor() {
        // save envConfig
        this._envConfig = {};
        // current keys used.
        this._currentKeys = [];
    }
    addFunction(specs) {
        this._envConfig = specs.reduce((prev, config) => {
            for (let key in config) {
                if (prev[key]) {
                    if (prev[key].required) {
                        config[key].required = prev[key].required;
                    }
                    if (prev[key].devRequired) {
                        config[key].devRequired = prev[key].devRequired;
                    }
                }
                return Object.assign(Object.assign({}, prev), config);
            }
        }, this._envConfig);
    }
    set currentKeys(keys) {
        this._currentKeys = keys;
    }
    get envConfig() {
        return this._envConfig;
    }
    get missedKeys() {
        return Object.keys(this._envConfig).filter(key => !this._currentKeys.includes(key));
    }
    get unUsedKeys() {
        const usedKeys = Object.keys(this._envConfig);
        return this._currentKeys.filter(key => !usedKeys.includes(key));
    }
    get requiredNodeEnv() {
        return Object.keys(this._envConfig).filter(key => !!this._envConfig[key].required || this._envConfig[key].required === undefined);
    }
    get devRequiredNodeEnv() {
        return Object.keys(this._envConfig).filter(key => !!this._envConfig[key].devRequired || this._envConfig[key].devRequired === undefined);
    }
    get optionalNodeEnv() {
        return Object.keys(this._envConfig).filter(key => { var _a; return ((_a = this._envConfig[key]) === null || _a === void 0 ? void 0 : _a.required) && !this._envConfig[key].required; });
    }
    printDetails() {
        if (this._currentKeys.length > 0) {
            const missed = this.missedKeys;
            if (missed.length > 0) {
                console.log('missed keys found in public-config file');
                console.log(missed);
            }
            const unUsedKeys = this.unUsedKeys;
            if (unUsedKeys.length > 0) {
                console.log('unused keys found in public-config file');
                console.log(unUsedKeys);
            }
        }
        const required = this.requiredNodeEnv;
        if (require.length > 0) {
            console.log('Informational: make sure your envirment has set following');
            console.log(required);
        }
        const optional = this.optionalNodeEnv;
        if (optional.length > 0) {
            console.log('optional env to set');
            console.log(optional);
        }
    }
}
// Export singleton for use by loader and plugin.
exports.default = new EnvStore();
//# sourceMappingURL=envStore.js.map